@@ -4,15 +4,15 @@ use strict;
 use warnings;
 use Carp ();
 
-$Test::Mock::Cmd::VERSION = '0.6';
+$Test::Mock::Cmd::VERSION = '0.7';
 
 sub import {
     if ( @_ == 3 || @_ == 5 || @_ == 7 ) {
         my ( $class, %override ) = @_;
 
         for my $k ( keys %override ) {
-            if ( $k ne 'system' && $k ne 'exec' && $k ne 'qr' ) {
-                Carp::croak('Key is not system, exec, or qr');
+            if ( $k ne 'system' && $k ne 'exec' && $k ne 'qx' ) {
+                Carp::croak('Key is not system, exec, or qx');
             }
             if ( ref( $override{$k} ) ne 'CODE' && ref( $override{$k} ) ne 'HASH' ) {
                 Carp::croak('Not a CODE or HASH reference');
@@ -22,7 +22,7 @@ sub import {
         no warnings 'redefine';
         *CORE::GLOBAL::system   = _transmogrify_to_code( $override{'system'}, \&orig_system ) if $override{'system'};
         *CORE::GLOBAL::exec     = _transmogrify_to_code( $override{'exec'},   \&orig_exec )   if $override{'exec'};
-        *CORE::GLOBAL::readpipe = _transmogrify_to_code( $override{'qr'},     \&orig_qr )     if $override{'qr'};
+        *CORE::GLOBAL::readpipe = _transmogrify_to_code( $override{'qx'},     \&orig_qx )     if $override{'qx'};
 
         return 1;
     }
@@ -42,7 +42,7 @@ sub import {
     no warnings 'redefine';
     *CORE::GLOBAL::system = _transmogrify_to_code( $_[1], \&orig_system );
     *CORE::GLOBAL::exec     = _transmogrify_to_code( $_[2] || $_[1], \&orig_exec );
-    *CORE::GLOBAL::readpipe = _transmogrify_to_code( $_[3] || $_[1], \&orig_qr );
+    *CORE::GLOBAL::readpipe = _transmogrify_to_code( $_[3] || $_[1], \&orig_qx );
 }
 
 # This doesn't make sense w/ the once-set-always-set behavior of these functions and it's just weird so we leave it out for now.
@@ -98,11 +98,11 @@ Test::Mock::Cmd - Mock system(), exec(), and qx() for testing
 
 =head1 VERSION
 
-This document describes Test::Mock::Cmd version 0.6
+This document describes Test::Mock::Cmd version 0.7
 
 =head1 SYNOPSIS
 
-    use Test::Mock::Cmd 'system' => \&my_cmd_mocker, 'qr' => \&my_cmd_mocker;
+    use Test::Mock::Cmd 'system' => \&my_cmd_mocker, 'qx' => \&my_cmd_mocker;
 
 or
 
@@ -114,7 +114,7 @@ or
 
 or
 
-    use Test::Mock::Cmd 'system' => { … }, 'qr' =>  { … }; # can mix and match hash ref and code ref
+    use Test::Mock::Cmd 'system' => { … }, 'qx' =>  { … }; # can mix and match hash ref and code ref
 
 or
 
@@ -196,7 +196,7 @@ etc etc
 
 =head2 Commence mocking
 
-Per the synopsis, you can provide import() with a hash whose keys are 'system', 'exec', or 'qr' and whose values are the code reference you want to replace the key's functionality with, 1 code reference to replace all 3 functions or 3 code references to replace system(), exec(), and qx() (in that order).
+Per the synopsis, you can provide import() with a hash whose keys are 'system', 'exec', or 'qx' and whose values are the code reference you want to replace the key's functionality with, 1 code reference to replace all 3 functions or 3 code references to replace system(), exec(), and qx() (in that order).
 
 As of v0.6 you can pass in a hash instead of a coderef that will generate a handler that defaults to the original call if the first argument given is not a key in said hash.
 
@@ -244,7 +244,7 @@ Original, not-mocked L<perlfunc/readpipe>
 
 The given value is not a code reference or a hash reference and should be one or the other.
 
-=item C<< Key is not system, exec, or qr >>
+=item C<< Key is not system, exec, or qx >>
 
 A key in your argument hash is invalid.
 
@@ -266,13 +266,10 @@ None.
 
 None reported.
 
-=head1 BUGS AND LIMITATIONS
+=head1 BUGS AND FEATURES
 
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-test-mock-cmd@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+Please report any bugs or feature requests (and a pull request for bonus points)
+ through the issue tracker at L<https://github.com/drmuey/p5-Test-Mock-Cmd/issues>.
 
 =head1 See Also
 
