@@ -33,7 +33,7 @@ sub tmp_stdout_like_rt_72976 {
         unlink "tmp.$$.tmp";
 
         no warnings 'once';
-        open OLDOUT, '>&STDOUT' or die "Could not dup STDOUT: $!";
+        open OLDOUT, '>&STDOUT' or die "Could not dup STDOUT: $!";    ## no critic
         close STDOUT;
 
         open STDOUT, '>', "tmp.$$.tmp" or die "Could not redirect STDOUT: $!";
@@ -42,7 +42,7 @@ sub tmp_stdout_like_rt_72976 {
         # open STDOUT, '>', \$output or die "Could not redirect STDOUT: $!";
 
         $func->();
-        open STDOUT, '>&OLDOUT' or die "Could not restore STDOUT: $!";
+        open STDOUT, '>&OLDOUT' or die "Could not restore STDOUT: $!";    ## no critic
 
         open my $fh, '<', "tmp.$$.tmp" or die "Could not open temp file: $!";
         while ( my $line = <$fh> ) {
@@ -67,4 +67,4 @@ Copyright (c) 2011 cPanel, Inc. C<< <copyright@cpanel.net>> >>. All rights reser
 
 This library is free software; you can redistribute it and/or modify it under 
 the same terms as Perl itself, either Perl version 5.10.1 or, at your option, 
-any later version of Perl 5 you may have available.
\ No newline at end of file
+any later version of Perl 5 you may have available.
